@@ -330,7 +330,7 @@ class TestDriveClientDownload:
                 client.export("test_id", format="invalid_format")
 
     @pytest.mark.parametrize(
-        "format_type", ["html", "pdf", "xlsx", "csv", "md", "rtf", "txt"]
+        "format_type", ["html", "pdf", "xlsx", "csv", "md", "rtf", "txt", "odt", "epub"]
     )
     def test_export_format_validation_valid_formats(self, format_type):
         """Test format validation for valid formats."""
@@ -476,3 +476,52 @@ class TestDriveClientDownload:
         client = DriveClient()
         extension = client._get_file_extension_for_format("txt")
         assert extension == "txt"
+
+    def test_export_google_doc_to_epub(self):
+        """Test export of Google Doc to EPUB format."""
+        client = DriveClient()
+
+        # Mock the Google Drive API service
+        mock_google_drive_service = MagicMock()
+
+        # Mock Google's export request
+        mock_google_export_request = MagicMock()
+        mock_google_export_request.execute.return_value = b"EPUB content here"
+        mock_google_drive_service.files().export.return_value = (
+            mock_google_export_request
+        )
+
+        # Mock Google's file metadata call for output path
+        mock_google_get_request = MagicMock()
+        mock_google_get_request.execute.return_value = {"name": "Test Document"}
+        mock_google_drive_service.files().get.return_value = mock_google_get_request
+
+        # Setup client with mocked Google service
+        client.service = mock_google_drive_service
+
+        with tempfile.TemporaryDirectory() as temp_dir:
+            output_path = os.path.join(temp_dir, "test.epub")
+            result = client.export("test_id", output_path=output_path, format="epub")
+
+            # Verify the correct MIME type was used for EPUB
+            mock_google_drive_service.files().export.assert_called_with(
+                fileId="test_id", mimeType="application/epub+zip"
+            )
+            assert result == output_path
+
+            # Verify the content was written correctly
+            with open(output_path, "rb") as f:
+                content = f.read()
+            assert content == b"EPUB content here"
+
+    def test_get_mime_type_for_epub_format(self):
+        """Test MIME type mapping for EPUB format."""
+        client = DriveClient()
+        mime_type = client._get_mime_type_for_format("epub")
+        assert mime_type == "application/epub+zip"
+
+    def test_get_file_extension_for_epub_format(self):
+        """Test file extension mapping for EPUB format."""
+        client = DriveClient()
+        extension = client._get_file_extension_for_format("epub")
+        assert extension == "epub"
